breeds [
  water       ;; blue molecules
  anions      ;; red molecules
]
          
globals [
  shrink      ;; how many steps right side has been shrunk
]

;; set up model with molecules randomly distributed across screen
to setup [both-sides?]
  ca
  set-default-shape turtles "circle"
  set shrink 0
  draw-walls
  create-custom-water 100         ;; makes 100 blue water molecules
    [ set color blue
      randomize ]                 ;; and puts them on both sides
  create-custom-anions 50         ;; makes 50 red anions
    [ set color red
      ifelse both-sides?          ;; and puts them on one or both sides depending
        [ randomize ]             ;; on which setup button was pressed
        [ randomize-right ] ]                  
  setup-plot
end

;;turtle procedure that randomizes heading and position
to randomize
  rt random 360.0
  setxy (random screen-size-x) (random screen-size-y)
  if any patches in-radius 1 with [pcolor = green]
    [ randomize ] ;; keep trying until we don't land on or near green
end

;; turtle procedure that randomizes heading and position on the
;; right side of the membrane
to randomize-right
  rt random 360.0
  setxy (random screen-edge-x) (random screen-size-y)
  if any patches in-radius 1 with [pcolor = green]
    [ randomize-right ] ;; try again until we don't land on or near green
end

;; observer procedure that makes the walls of the box
to draw-walls
  ;; don't let the window be bigger than the right chamber
  if (window-edge > (screen-edge-y - shrink))
    [ set window-edge (screen-edge-y - shrink) ]
  ask patches with [(pxcor = 0 - screen-edge-x) or
                    ((pxcor < 0) and (abs pycor = screen-edge-y)) or
                    (pxcor >= screen-edge-x - shrink) or
                    ((pxcor > 0) and (abs pycor >= screen-edge-y - shrink))]
    [ set pcolor green ]
  ask patches with [pxcor = 0]
    [ ifelse abs pycor < window-edge
        [ set pcolor black ]
        [ set pcolor green ] ]
  ;; make sure no turtles are embedded in the middle wall
  ;; if the window size changed
  ask turtles with [(pxcor = 0) and (pcolor = green)]
    [ randomize ]
end

to go
  ask turtles
    [ bounce
      fd 1 ]
  do-plot
end

;;observer procedure used to place 25 more red anions on the right
to add-anions-right
  create-custom-anions 25
    [ set color red 
      randomize-right ]
end

to bounce ;; turtle procedure
  ;; Note: The minimum on the window-edge slider is 2, not 0 or 1, because
  ;; this code does not correctly hande the case where window-edge is 1
  ;; (sometimes molecules get stuck in the window).
  locals [box-edge-x box-edge-y new-px new-py]
  ; if we're not about to land on green, we don't need to do any
  ; further checks
  if pcolor-of patch-at dx dy != green [ stop ]
  ; figure out where the walls are on this side of the box
  ifelse xcor < 0
    [ set box-edge-x screen-edge-x
      set box-edge-y screen-edge-y ]
    [ set box-edge-x screen-edge-x - shrink
      set box-edge-y screen-edge-y - shrink ]
  ; get the coordinates of the patch we'll be on if we go forward 1
  set new-px round (xcor + dx)
  set new-py round (ycor + dy)
  ; check: hitting left, right, or middle wall?
  if (abs new-px = box-edge-x) or
     ((new-px = 0) and (pxcor != 0))
    ; if so, reflect heading around x axis
    [ set heading (0 - heading) ]
  ; check: hitting top or bottom wall, or edge of middle wall?
  if (abs new-py = box-edge-y) or
     ((new-px = 0) and (pxcor = 0))
    ; if so, reflect heading around y axis
    [ set heading (180 - heading) ]
end

;; observer procedure that causes right side of divider to shrink (if amount is
;; positive) or expand (if amount is negative)
to shrink-or-expand [amount]
  set shrink (shrink + amount)
  ;; keep it within bounds
  if (shrink < 0)
    [ set shrink 0 ]
  if (shrink >= screen-edge-x - 2)
    [ set shrink screen-edge-x - 2 ]
  if (shrink >= screen-edge-y - 2)
    [ set shrink screen-edge-y - 2 ]
  ;; use no-display so user doesn't see molecules being shuffled around
  no-display
  clear-patches
  draw-walls
  ;; make sure no turtles are embedded in the walls
  ask turtles with [(xcor > 0) and (pcolor = green)]
    [ randomize-right ]
  display
end

;;; plotting procedures

to setup-plot
  ;; draw the x axis in black
  set-current-plot "Equilibration Plot"
  auto-plot-off
  set-current-plot-pen "midline"
  plot 0
  plotxy 10000 0
  auto-plot-on
end

to do-plot
  locals [anions-left anions-right
          water-left water-right]
  set anions-left count anions with [xcor < 0]
  set anions-right count anions with [xcor >= 0]
  set water-left count water with [xcor < 0]
  set water-right count water with [xcor >= 0]
  set-current-plot "Equilibration Plot"
  set-current-plot-pen "anions"
  plot (anions-right - anions-left)
  set-current-plot-pen "water"
  plot (water-right - water-left)
end


; *** NetLogo Model Copyright Notice ***
;
; This model was created as part of the project:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN
; CLASSROOMS.  The project gratefully acknowledges the support of the
; National Science Foundation (REPP program) -- grant number REC #9814682.
;
; Copyright 2001 by Uri Wilensky.  Updated 2002.  All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (2001).  NetLogo Simple Kinetics 3 model.
; http://ccl.northwestern.edu/netlogo/models/SimpleKinetics3.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
258
10
583
356
17
17
9.0
1
10
0
0

CC-WINDOW
258
358
573
495
Command Center

BUTTON
2
41
94
74
setup random
setup true\n;; true = reds on\n;; both sides
NIL
1
T
OBSERVER

BUTTON
2
75
94
108
setup side
setup false\n;; false = reds all on\n;; one side
NIL
1
T
OBSERVER

BUTTON
98
41
167
74
go
go
T
1
T
OBSERVER

BUTTON
168
41
252
74
add red
add-anions-right
NIL
1
T
OBSERVER

BUTTON
30
149
126
182
shrink right
shrink-or-expand 1
NIL
1
T
OBSERVER

BUTTON
127
149
230
182
expand right
shrink-or-expand -1
NIL
1
T
OBSERVER

MONITOR
131
263
213
312
anions-right
count anions with\n[xcor >= 0]
3
1

MONITOR
45
263
123
312
anions-left
count anions with\n[xcor < 0]
3
1

BUTTON
144
187
250
220
change window
draw-walls
NIL
1
T
OBSERVER

SLIDER
20
187
143
220
window-edge
window-edge
2
12
2
1
1
NIL

PLOT
6
313
256
495
Equilibration Plot
Time
Number
0.0
100.0
-100.0
100.0
true
true
PENS
"anions" 1.0 0 -65536 true
"water" 1.0 0 -16776961 true
"midline" 1.0 0 -16777216 false

@#$#@#$#@
WHAT IS IT?
------------
This model follows on the Simple Kinetics 2 model.  In Simple Kinetics 2, we saw how changes to variables such as temperature, volume, and concentration affected the rate at which a chemical reaction reached an equilibrium state.  Here we model the same phenomenon based upon a physical separation.

This model investigates some laboratory methods that chemists use to purify chemicals.  Most of these methods are based upon physical properties of molecular separation. The same principles that affect chemical equilibrium affect physical equilibrium as well. By changing the variables of temperature, volume, and concentration, we can affect not only the speed at which a system reaches equilibrium, but also the nature of the distribution ratio. In this model, we watch how these factors affect the physical distribution of red molecules that are considered "dissolved" in a blue solvent.


HOW TO USE IT
-------------
Setup the model by pressing either the SETUP-RANDOM or the SETUP-SIDE buttons at the top of the Interface tab.  SETUP-RANDOM distributes all the molecules randomly around the screen. SETUP-SIDE distributes the blue molecules evenly, while placing the red molecules on the right side of the screen.

Press GO to watch the molecules move about the screen as they achieve equilibrium. The plot tracks the relative concentrations of each color molecule on each side of the central divider. If the red line dips below 0, there are more red molecules on the left side of the divider than on the right. If it rises above 0, there are more red molecules on the right side of the divider than on the left. The blue line plots the same relationship for blue molecules.

You can add more red molecules to the right side of the screen by pressing ADD RED. 

Similarly, you can shrink or expand the right side of the box with the buttons SHRINK RIGHT and EXPAND RIGHT, respectively.

Finally, to change the size of the connection window, move the WINDOW slider to your desired size and then press the CHANGE WINDOW button. 


THINGS TO NOTICE
----------------
Pay attention to the plot and compare it what you see in the graphics screen. Is there an equal number of blue and red molecules on each side of the divider according to the plot and according to what you perceive in the graphics screen?


THINGS TO TRY
-------------
Run the model with several different states for each variable. Do you observe similar equilibrium effects to those seen in Simple Kinetics 2?  Are there significant differences?

Does the temperature affect the system in the same way it affected the chemical reaction in Simple Kinetics 2?  Why or why not?

How does changing the concentration affect the rate at which the molecules achieve equilibrium? Does this make sense?


EXTENDING THE MODEL
-------------------
The system we have established here always comes to an approximately identical equilibrium state, no matter how you change the variables. In the lab, this is not useful to chemists, who want to separate one type of molecule from another. Can you extend the model to separate all of the red molecules from the blue molecules?

Try adding another color of molecule to the system and randomly distributing all the molecules around the screen. Can you devise a way to separate the new molecules from the red molecules?

Add a slider that allows you to alter the temperature of the system. Think about what effect cooling and heating the system would have on the molecules. Be sure to include a command in the procedures window that will execute your proposed effect.


RELATED MODELS
--------------
Simple Kinetics 1, Simple Kinetics 2.  Note that the original StarLogoT version of this model was named "Le Chatelier 2".


CREDITS AND REFERENCES
----------------------
Thanks to Mike Stieff for his work on this model.

To refer to this model in academic publications, please use: Wilensky, U. (2001).  NetLogo Simple Kinetics 3 model. http://ccl.northwestern.edu/netlogo/models/SimpleKinetics3. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

arrow
true
0
Polygon -7566196 true true 150 300 300 150 195 150 195 7 105 7 105 150 105 150 0 150

box
true
0
Polygon -7566196 true true 45 255 255 255 255 45 45 45

circle
true
0
Circle -7566196 true true 89 90 122

person
false
0
Circle -7566196 true true 155 20 63
Rectangle -7566196 true true 158 79 217 164
Polygon -7566196 true true 158 81 110 129 131 143 158 109 165 110
Polygon -7566196 true true 216 83 267 123 248 143 215 107
Polygon -7566196 true true 167 163 145 234 183 234 183 163
Polygon -7566196 true true 195 163 195 233 227 233 206 159

spacecraft
true
0
Polygon -7566196 true true 150 300 120 165 45 45 75 60 150 120 225 60 255 45 180 165

thin-arrow
true
0
Polygon -7566196 true true 150 300 300 150 180 150 180 4 120 4 120 150 120 150 0 150

truck-down
false
0
Polygon -7566196 true true 225 30 225 270 120 270 105 210 60 180 45 30 105 60 105 30
Polygon -8716033 true false 195 75 195 120 240 120 240 75
Polygon -8716033 true false 195 225 195 180 240 180 240 225

truck-left
false
0
Polygon -7566196 true true 120 135 225 135 225 210 75 210 75 165 105 165
Polygon -8716033 true false 90 210 105 225 120 210
Polygon -8716033 true false 180 210 195 225 210 210

truck-right
false
0
Polygon -7566196 true true 180 135 75 135 75 210 225 210 225 165 195 165
Polygon -8716033 true false 210 210 195 225 180 210
Polygon -8716033 true false 120 210 105 225 90 210

turtle
true
0
Polygon -7566196 true true 138 75 162 75 165 105 225 105 225 142 195 135 195 187 225 195 225 225 195 217 195 202 105 202 105 217 75 225 75 195 105 187 105 135 75 142 75 105 135 105

@#$#@#$#@
NetLogo 1.3beta1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
